@@ -1,6 +1,6 @@
 /* gcjwebplugin - web browser plug-in to execute Java (tm) applets
-   Copyright (C) 2003  Michael Koch <konqueror@gmx.de>
-   Copyright (C) 2003  Thomas Fitzsimmons <fitzsim@redhat.com>
+   Copyright (C) 2003, 2004  Michael Koch <konqueror@gmx.de>
+                             Thomas Fitzsimmons <fitzsim@redhat.com>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -41,6 +41,9 @@
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <errno.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 
 #include "config.h"
 #include "pluginDebug.h"
@@ -509,32 +512,60 @@ NP_Initialize(NPNetscapeFuncs* browserTable, NPPluginFuncs* pluginTable)
   pluginTable->urlnotify = NewNPP_URLNotifyProc(GCJ_URLNotify);
   pluginTable->getvalue = NewNPP_GetValueProc(GCJ_GetValue);
 
-  GError *err = NULL;
-  gint output_to_gcjappletviewer_fd;
-  gint input_from_gcjappletviewer_fd;
-  gchar *command_line [3] = { "gcjappletviewer", "--plugin", NULL };
+  // Create named pipes.
+  gchar *pipename_in = g_strdup_printf ("/tmp/gcjwebplugin-%i-in", getpid ());
+  gchar *pipename_out = g_strdup_printf ("/tmp/gcjwebplugin-%i-out", getpid ());
+  
+  if (mkfifo (pipename_in, 0700) == -1
+      && errno != EEXIST)
+    {
+      g_printerr ("GCJ_New: Error: %s\n", strerror (errno));
+      return NPERR_GENERIC_ERROR;
+    }
 
-  if (!g_spawn_async_with_pipes (NULL,
-				 command_line,
-                                 NULL,
-                                 G_SPAWN_SEARCH_PATH,
-                                 NULL,
-                                 NULL,
-                                 NULL,
-                                 &output_to_gcjappletviewer_fd,
-                                 &input_from_gcjappletviewer_fd,
-                                 NULL,
-                                 &err))
+  if (mkfifo (pipename_out, 0700) == -1
+      && errno != EEXIST)
+    {
+      g_printerr ("GCJ_New: Error: %s\n", strerror (errno));
+      return NPERR_GENERIC_ERROR;
+    }
+  
+  GError *err = NULL;
+  gchar *command_line [3] = { "gcjappletviewer",
+			      g_strdup_printf ("--plugin=%s,%s",
+					       pipename_in,
+					       pipename_out),
+			      NULL };
+
+  if (!g_spawn_async (NULL,
+		      command_line,
+		      NULL,
+		      G_SPAWN_SEARCH_PATH,
+		      NULL,
+		      NULL,
+		      NULL,
+		      &err))
     {
       g_printerr ("GCJ_New: Error: %s\n", err->message);
       return NPERR_GENERIC_ERROR;
     }
 
-  output_to_appletviewer = g_io_channel_unix_new (output_to_gcjappletviewer_fd);
-  input_from_appletviewer = g_io_channel_unix_new (input_from_gcjappletviewer_fd);
-
   g_printerr ("Spawned gcjappletviewer successfully.\n");
 
+  output_to_appletviewer = g_io_channel_new_file (pipename_in, "w", &err);
+  if (!output_to_appletviewer)
+    {
+      g_printerr ("GCJ_New: Error: %s\n", err->message);
+      return NPERR_GENERIC_ERROR;
+    }
+  
+  input_from_appletviewer = g_io_channel_new_file (pipename_out, "r", &err);
+  if (!input_from_appletviewer)
+    {
+      g_printerr ("GCJ_New: Error: %s\n", err->message);
+      return NPERR_GENERIC_ERROR;
+    }
+
   NPError np_error;
   if ((np_error = receive_message_from_appletviewer ("running")) != NPERR_NO_ERROR)
     return np_error;
