@@ -49,6 +49,9 @@ class AppletTag
   // here anyway, for convenience.
   URL documentbase;
 
+  // Same goes for the HTML file's character encoding.
+  String encoding;
+
   // Default constructor needed by derived classes.
   AppletTag ()
   {
@@ -57,9 +60,10 @@ class AppletTag
   // Construct an applet tag object from a .class file and the user's
   // current directory.
   AppletTag (String code, String archives,
-	     List parameters, Dimension dimensions)
+	     List parameters, Dimension dimensions, String encoding)
     throws MalformedURLException, IOException
   {
+    this.encoding = encoding;
     // Calculate code.
     this.code = code.substring(code.lastIndexOf(File.separatorChar) + 1,
                                code.length());
@@ -98,10 +102,11 @@ class AppletTag
 
   // Construct an applet tag object from an HTML stream.
   AppletTag (StreamTokenizer tagTokenizer,
-	     URL documentbase)
+	     URL documentbase, String encoding)
     throws IOException
   {
     this.documentbase = documentbase;
+    this.encoding = encoding;
     dimensions = new Dimension (0, 0);
 
     while (tagTokenizer.nextToken() != '>')
@@ -336,7 +341,7 @@ class AppletTag
 
   // Return a list of applet tag objects representing the applet tags
   // that appear in the file or URL "location."
-  static List parseAppletTags (String location)
+  static List parseAppletTags (String location, String encoding)
     throws IOException
   {
     ArrayList tags = new ArrayList ();
@@ -349,17 +354,18 @@ class AppletTag
     input = documentbase.openStream ();
     tagTokenizer = new StreamTokenizer(new InputStreamReader(input));
 
-    currentTag = parseNextTag (tagTokenizer, documentbase);
+    currentTag = parseNextTag (tagTokenizer, documentbase, encoding);
     while (currentTag != null)
       {
 	tags.add (currentTag);
-	currentTag = parseNextTag (tagTokenizer, documentbase);
+	currentTag = parseNextTag (tagTokenizer, documentbase, encoding);
       }
     return tags;
   }
 
   // Parse the next applet tag in the tagTokenizer stream.
-  static AppletTag parseNextTag (StreamTokenizer tagTokenizer, URL documentbase)
+  static AppletTag parseNextTag (StreamTokenizer tagTokenizer, URL documentbase,
+				 String encoding)
     throws IOException
   {
     AppletTag currentTag = null;
@@ -381,16 +387,20 @@ class AppletTag
                 // An APPLET tag.
                 if (tagTokenizer.sval.equals("applet"))
                   currentTag = new AppletTag(tagTokenizer,
-                                             documentbase);
+                                             documentbase,
+					     encoding);
                 else if (tagTokenizer.sval.equals("embed"))
                   currentTag = new EmbedTag(tagTokenizer,
-                                            documentbase);
+                                            documentbase,
+					    encoding);
                 else if (tagTokenizer.sval.equals("object"))
                   currentTag = new ObjectTag(tagTokenizer,
-                                             documentbase);
+                                             documentbase,
+					     encoding);
                 else if (tagTokenizer.sval.equals("app"))
                   currentTag = new AppTag(tagTokenizer,
-                                          documentbase);
+                                          documentbase,
+					  encoding);
                 else if (tagTokenizer.sval.equals("param"))
                   {
                     // Parse APPLET parameters only.
@@ -445,10 +455,11 @@ class AppletTag
 
 class EmbedTag extends AppletTag
 {
-  EmbedTag (StreamTokenizer tagTokenizer, URL documentbase)
+  EmbedTag (StreamTokenizer tagTokenizer, URL documentbase, String encoding)
     throws IOException
   {
     this.documentbase = documentbase;
+    this.encoding = encoding;
     dimensions = new Dimension (0, 0);
 
     // In an EMBED tag, a parameter is any non-standard attribute.  This
@@ -618,10 +629,11 @@ class ObjectTag extends AppletTag
   boolean javaArchiveSet = false;
   boolean javaObjectSet = false;
 
-  ObjectTag (StreamTokenizer tagTokenizer, URL documentbase)
+  ObjectTag (StreamTokenizer tagTokenizer, URL documentbase, String encoding)
     throws IOException
   {
     this.documentbase = documentbase;
+    this.encoding = encoding;
     dimensions = new Dimension (0, 0);
 
     while (tagTokenizer.nextToken() != '>')
@@ -757,10 +769,11 @@ class ObjectTag extends AppletTag
 
 class AppTag extends AppletTag
 {
-  AppTag (StreamTokenizer tagTokenizer, URL documentbase)
+  AppTag (StreamTokenizer tagTokenizer, URL documentbase, String encoding)
     throws IOException
   {
     this.documentbase = documentbase;
+    this.encoding = encoding;
     dimensions = new Dimension (0, 0);
 
     while (tagTokenizer.nextToken() != '>')
