@@ -1,5 +1,5 @@
 /* AppletViewer.java -- a standalone viewer for Java applets
-   Copyright (C) 2003  Thomas Fitzsimmons <fitzsim@redhat.com>
+   Copyright (C) 2003, 2004  Thomas Fitzsimmons <fitzsim@redhat.com>
 
    This file is part of GCJ Applet Viewer.
 
@@ -24,11 +24,18 @@ import gnu.getopt.Getopt;
 import gnu.getopt.LongOpt;
 import java.applet.Applet;
 import java.awt.Dimension;
+import java.io.FileInputStream;
+import java.io.FileOutputStream;
 import java.io.IOException;
 import java.net.URL;
 import java.net.URLClassLoader;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Iterator;
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.LinkedList;
+import java.util.Vector;
 
 class AppletViewer
 {
@@ -37,6 +44,7 @@ class AppletViewer
   static Applet createApplet (AppletTag tag)
   {
     Applet applet = null;
+
     try
       {
         URLClassLoader loader;
@@ -79,18 +87,98 @@ class AppletViewer
     System.out.println ("  --width=<width>                   Set width of applet viewer frame");
     System.out.println ("  --height=<height>                 Set height of applet viewer frame");
     System.out.println ("  --plugin                          Enable plugin mode");
+    System.out.println ("  -debug                            For appletviewer compatibility");
+    System.out.println ("  -encoding <encoding>              Specify character encoding used by HTML files");
+    System.out.println ("  -J<runtime flag>                  Pass argument to the Java runtime");
     System.exit (status);
   }
 
   public static void main (String[] args)
     throws IOException
   {
+    String encoding = "UTF8";
+
     if (args.length == 0)
       {
-	System.out.println ("gcjappletviewer: no input files");
+	System.err.println ("gcjappletviewer: no input files");
 	printHelpMessage (1);
       }
 
+    List argsList = new LinkedList (Arrays.asList (args));
+
+    // Check for the -debug option, for appletviewer compatibility.
+    // The -debug option can be given multiple times on the command
+    // line.
+
+    // FIXME: The debug option will be unsupported until we have the
+    // ability to debug bytecode.  For now, just strip it out of the
+    // argument list.
+    Iterator argsIter = argsList.iterator ();
+    while (argsIter.hasNext ())
+      {
+	String currentArg = (String) argsIter.next ();
+	if (currentArg.equals ("--"))
+	  break;
+	else if (currentArg.equals ("-debug"))
+	  argsIter.remove ();
+      }
+
+    // Check for the -encoding option, for appletviewer compatibility.
+    // The -encoding option can be given multiple times on the command
+    // line.  The last occurence wins.
+
+    // FIXME: We should probably be using
+    // java.nio.charset.CharsetDecoder to handle the encoding.  What
+    // is the status of Classpath's implementation?
+    argsIter = argsList.iterator ();
+    while (argsIter.hasNext ())
+      {
+	String currentArg = (String) argsIter.next ();
+	if (currentArg.equals ("--"))
+	  break;
+	else if (currentArg.equals ("-encoding"))
+	  {
+	    if (!argsIter.hasNext ())
+	      {
+		System.err.println ("gcjappletviewer: option '-encoding' requires an argument");
+		printHelpMessage (1);
+	      }
+	    // Remove the -encoding option.
+	    argsIter.remove ();
+	    encoding = (String) argsIter.next ();
+	    // Remove the argument to -encoding.
+	    argsIter.remove ();
+	  }
+      }
+
+    // Check for -J options, for appletviewer compatibility.
+
+    // FIXME: currently we ignore these options.  What are their gcj
+    // equivalents and how do we pass them to the runtime?
+    argsIter = argsList.iterator ();
+    while (argsIter.hasNext ())
+      {
+	String currentArg = (String) argsIter.next ();
+	
+	if (currentArg.length () == 2)
+	  {
+	    if (currentArg.equals ("--"))
+	      break;
+	    else if (currentArg.equals ("-J"))
+	      {
+		System.err.println ("gcjappletviewer: the -J option should not be followed by a space.");
+		printHelpMessage (1);
+	      }
+	  }
+	else if (currentArg.length () > 2)
+	  {
+	    if (currentArg.substring (0, 2).equals ("-J"))
+	      argsIter.remove ();
+	  }
+      }
+
+    args = (String[]) argsList.toArray (new String [argsList.size ()]);
+
     LongOpt[] longOptions = new LongOpt[]
       {
 	new LongOpt ("code",     LongOpt.REQUIRED_ARGUMENT, null, 0),
@@ -99,7 +187,7 @@ class AppletViewer
 	new LongOpt ("param",    LongOpt.REQUIRED_ARGUMENT, null, 0),
 	new LongOpt ("width",    LongOpt.REQUIRED_ARGUMENT, null, 0),
 	new LongOpt ("height",   LongOpt.REQUIRED_ARGUMENT, null, 0),
-	new LongOpt ("plugin",   LongOpt.NO_ARGUMENT,       null, 0),
+	new LongOpt ("plugin",   LongOpt.REQUIRED_ARGUMENT, null, 0),
 	new LongOpt ("help",     LongOpt.NO_ARGUMENT,       null, 0),
       };
 
@@ -113,6 +201,8 @@ class AppletViewer
     String archives = "";
     List parameters = new ArrayList ();
     Dimension dimensions = new Dimension (-1, -1);
+    String pipeInName = "";
+    String pipeOutName = "";
 
     boolean codeGiven = false;
     boolean widthGiven = false;
@@ -154,6 +244,10 @@ class AppletViewer
 	    else if (optionIndex == 6) // --plugin
 	      {
 		pluginMode = true;
+		String tmp = opts.getOptarg();
+		int pos = tmp.indexOf(',');
+		pipeInName = tmp.substring(0, pos);
+		pipeOutName = tmp.substring(pos + 1);
 		break;
 	      }
 	    else if (optionIndex == 7) // --help
@@ -170,13 +264,18 @@ class AppletViewer
     System.err.println (dimensions);
 
     if (pluginMode)
-      PluginAppletViewer.start (System.in, System.out);
+      {
+	FileInputStream in = new FileInputStream(pipeInName);
+	FileOutputStream out = new FileOutputStream(pipeOutName);
+	PluginAppletViewer.start (in, out);
+      }
     else
       new StandaloneAppletViewer (code, codebase,
 				  archives, parameters,
 				  dimensions,
 				  widthGiven, heightGiven,
 				  codeGiven,
-				  args, opts, opts.getOptind ());
+				  args, opts, opts.getOptind (),
+				  encoding);
   }
 }
