@@ -90,7 +90,7 @@ class PluginAppletViewer
 	    String documentbase = read ();
 	    String tag = read ();
 
-	    currentWindow.setTag (tag, documentbase);
+	    currentWindow.setTag (tag, documentbase, "UTF8");
 	  }
 	else if (input.equals ("xid"))
 	  {
