@@ -48,13 +48,13 @@ class PluginAppletWindow extends EmbeddedWindow
     super ();
   }
 
-  void setTag (String tag, String documentbase)
+  void setTag (String tag, String documentbase, String encoding)
     throws MalformedURLException, IOException
   {
     StringReader reader = new StringReader (tag);
     URL documentbaseURL = AppletTag.locationToURL (documentbase);
     this.tag = AppletTag.parseNextTag (new StreamTokenizer (reader),
-				       documentbaseURL);
+				       documentbaseURL, encoding);
   }
 
   ///////////////////////////////////
