@@ -29,6 +29,8 @@ import java.awt.Label;
 import java.awt.Menu;
 import java.awt.MenuBar;
 import java.awt.MenuItem;
+import java.awt.event.ActionListener;
+import java.awt.event.ActionEvent;
 import java.awt.event.WindowAdapter;
 import java.awt.event.WindowEvent;
 import java.util.HashMap;
@@ -66,10 +68,19 @@ class StandaloneAppletWindow extends Frame
 
     addNotify();
 
+    MenuItem quitItem = new MenuItem ("Quit");
+    quitItem.addActionListener (new ActionListener ()
+      {
+	public void actionPerformed (ActionEvent e)
+	{
+	  System.out.println ("Quit Hit");
+	}
+      });
+
     MenuBar menuBar = new MenuBar();
-    Menu menuFile = new Menu ("File");
+    Menu menuFile = new Menu ("Applet");
     menuBar.add (menuFile);
-    menuFile.add (new MenuItem ("Quit"));
+    menuFile.add (quitItem);
     setMenuBar (menuBar);
 
     AppletContext context = (AppletContext) contexts.get (tag.codebase);
@@ -84,7 +95,7 @@ class StandaloneAppletWindow extends Frame
     applet.init();
     applet.start();
 
-    setTitle (tag.documentbase.toString ());
+    setTitle ("GCJ Applet Viewer: " + tag.code);
     Insets insets = getInsets ();
     setSize (tag.dimensions.width + insets.left + insets.right,
 	     tag.dimensions.height + insets.top + insets.bottom);
